extensions[ gis ]
globals[ bnd-dataset pest-dataset ashba-dataset risk-dataset  ]

patches-own[ ashba n-beetles n-eggs days-infested t-infested health risk ]
turtles-own[ brood eggs-laid days-feeding days-alive life-expectance hatch-time t-feeding t-larva
             t-prepupa life-cycle-stage mature mate sex ]

to setup
  clear-all-but-globals  ; keeps GIS data values
  if use-random-seed [ random-seed 47822 ]
  read-gis-datasets
  setup-world-envelope
  draw-world
  sample-data
  
  ask patches  ; sets the legnth of time trees within a cell will be infested before it will be killed.
  [ if ashba > 0.09 AND ashba <= 1.0 [ set t-infested 365 ]
    if ashba > 1.0  AND ashba <= 2.0 [ set t-infested 365 + random(730 - 365 + 1) ]
    if ashba > 2.0  AND ashba <= 3.0 [ set t-infested 730 + random(1095 - 730 + 1) ]
    if ashba > 3.0                   [ set t-infested 730 + random(1460 - 730 + 1) ]
  ]
  
  foreach gis:feature-list-of pest-dataset ; uses known locations of infested trees to initialize the EAB population.
  [ let i 0
    ifelse i = 14 [ stop ]
    [ let loc gis:location-of (first (first (gis:vertex-lists-of ?) ) )

      if not empty? loc
      [  crt 30 + random (60 - 30 + 1)
         [  set xcor item 0 loc
            set ycor item 1 loc
            set size 1
            set life-cycle-stage "adult"
            set days-alive 365
            set life-expectance 365 + 21 + random(42 - 21 + 1)
            set t-feeding 5 + random(7 - 5 + 1)
            let num random 2 ; assumes a 1:1 female:male ratio
            if num = 0 [ set sex "female" ]
            if num = 1 [ set sex "male" ]
            ifelse sex = "female" [ set color pink ] [ set color blue ]
         ]
      ]
     set i i + 1
    ]
  ]
end

to go
  ask patches [ cal-health ]
  
  ask turtles
  [ set days-alive days-alive + 1
  
    if life-cycle-stage = "adult"
    [ if days-alive >= 365
      [ emerge
        if sex = "female" AND mate = 1 AND days-feeding > t-feeding [ lay-eggs ]
      ]
      if days-alive = life-expectance [ die ]
    ]
  
    cal-life-stage

    ; EAB juvienile mortality dynamics
    if life-cycle-stage = "egg"  AND days-alive >= egg-days-alive        ; Assumes a 0.5-1% mortality rate for eggs per day
    [ ask n-of ( count turtles with [ life-cycle-stage = "egg" ] * ( 0.005 + random-float( 0.01 - 0.005 + 0.001 ))) turtles with [ life-cycle-stage = "egg" ] [ die ] ]
    if life-cycle-stage = "larva" AND days-alive >= larva-days-alive     ; Assumes a 11-32% mortality rate for larva per day
    [ ask n-of ( count turtles with [ life-cycle-stage = "larva" ] * ( 0.11 + random-float( 0.32 - 0.11 + 0.1 ))) turtles with [ life-cycle-stage = "larva" ] [ die ] ]
    if life-cycle-stage = "prepupa" AND days-alive >= prepupa-days-alive  ; Assumes a 1-3% mortality rate for prepupa per day
    [ ask n-of ( count turtles with [ life-cycle-stage = "prepupa" ] * ( 0.01 + random-float( 0.03 - 0.01 + 0.01 ))) turtles with [ life-cycle-stage = "prepupa" ] [ die ] ]
  ]

  update-plot
  tick
end

to cal-health
  ifelse count turtles-here > 0
  [ set days-infested days-infested + 1
    set health "infested"
    set pcolor 17
  ]
  [ if ashba > 0.09 [ set health "healthy" ] ]
  set n-beetles count turtles-here
  set n-eggs count turtles-here with [ life-cycle-stage = "egg" ]
  if days-infested > t-infested [ set health "dead" set pcolor 12 ]
end

to emerge
  ifelse [ health ] of patch-here = "dead" ; assumes emerging adults will find healthier trees if their host tree is dead.
  [ disperse ]
  [ feed ]
end

to disperse
  let compass [ 0 45 90 135 180 225 270 315 ]
  
  set heading one-of compass fd 1 + random(4 - 1 + 1) ; assumes adults can move a maximium of 810 m per flight (270 m cells).
  select-host
end

to select-host
  ifelse [ health ] of patch-here = "healthy"
  [ feed ]
  [ ifelse [ health ] of patch-here = "infested"
    [ feed ]
    [ ifelse [ health ] of patch-here = "dead"
      [ disperse ] [ die ] ; allows beetles to fly outside the county and removes them from the population.
    ]
  ]
end

to feed
  ifelse [ health ] of patch-here = "dead"
  [ disperse ]
  [ ifelse days-feeding <= t-feeding
    [ set days-feeding days-feeding + 1 ]
    [ if sex = "female" AND count turtles-here with [ sex = "male" ] > 0
      [ set mate 1
        set brood 15 + random(30 - 15 + 1)
      ]
      set days-feeding 0
    ]
  ]
end

to lay-eggs
  set eggs-laid eggs-laid + brood
  hatch brood
  [ set life-cycle-stage "egg"
    set hatch-time 14 + random (21 - 14 + 1)
    set days-alive 0
    set days-feeding 0
    set t-feeding 5 + random(7 - 5 + 1)
    set brood 0
    set t-larva 16 + random(24 - 16 + 1)
    set t-prepupa 139 + random(169 - 139 + 1)
    set mature 352 + random (365 - 352 + 1)
    set life-expectance mature + 21 + random(42 - 21 + 1)
    set mate 0
    let num random 2
    if num = 0 [ set sex "female" set color pink ]
    if num = 1 [ set sex "male" set color blue ]
  ]
end

to cal-life-stage
  if life-cycle-stage = "egg"     AND days-alive = hatch-time [ set life-cycle-stage "larva" ]
  if life-cycle-stage = "larva"   AND days-alive = t-larva    [ set life-cycle-stage "prepupa" ]
  if life-cycle-stage = "prepupa" AND days-alive = t-prepupa  [ set life-cycle-stage "pupa" ]
  if life-cycle-stage = "pupa"    AND days-alive = mature     [ set life-cycle-stage "adult" ]
end

to update-plot
  ;; plot beetle population
  set-current-plot "Population"
  set-current-plot-pen "Eggs"
  plot count turtles with [ life-cycle-stage = "egg" ]
  set-current-plot-pen "larva"
  plot count turtles with [ life-cycle-stage = "larva" ]
  set-current-plot-pen "prepupa"
  plot count turtles with [ life-cycle-stage = "prepupa" ]
  set-current-plot-pen "pupa"
  plot count turtles with [ life-cycle-stage = "pupa" ]
  set-current-plot-pen "adult"
  plot count turtles with [ life-cycle-stage = "adult" ]

  
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;            GIS DATA            ;

to read-gis-datasets
  gis:load-coordinate-system "DATA/delaware.prj"
  set bnd-dataset    gis:load-dataset "DATA/delaware.shp"
  set pest-dataset   gis:load-dataset "DATA/eab_finds.shp"
  set risk-dataset   gis:load-dataset "DATA/risk.asc"
  set ashba-dataset  gis:load-dataset "DATA/ashba.asc"
end

to setup-world-envelope
  let world (gis:envelope-of bnd-dataset) ;; [ minimum-x maximum-x minimum-y maximum-y ]
  gis:set-world-envelope (world)
end

to sample-data
  ask patches
  [ gis:set-sampling-method ashba-dataset  "BICUBIC" set ashba  gis:raster-sample ashba-dataset self
    gis:set-sampling-method risk-dataset   "BICUBIC" set risk   gis:raster-sample risk-dataset self
  ]
end

to draw-world
  display-pest
  display-ashba
  display-risk
end

to clear-all-but-globals reset-ticks ct cp cd clear-links clear-all-plots clear-output end

to display-pest
  if GIS-pest [ gis:set-drawing-color [214 124   0]    gis:fill pest-dataset 2 ]
end
to display-ashba
  if GIS-ashba
  [ ask patches
    [ gis:set-sampling-method ashba-dataset  "BICUBIC" set ashba  gis:raster-sample ashba-dataset self
      if pcolor != 12 OR pcolor != 17  AND ashba < 0.1                   [ set pcolor 39 ]
      if pcolor != 12 OR pcolor != 17  AND ashba > 0.09 AND ashba <= 1.0 [ set pcolor 68 ]
      if pcolor != 12 OR pcolor != 17  AND ashba > 1.0  AND ashba <= 2.0 [ set pcolor 58 ]
      if pcolor != 12 OR pcolor != 17  AND ashba > 2.0  AND ashba <= 3.0 [ set pcolor 56 ]
      if pcolor != 12 OR pcolor != 17  AND ashba > 3.0                   [ set pcolor 54 ]
    ]
  ]
end
to display-risk
  if GIS-risk 
  [ ask patches
    [ gis:set-sampling-method risk-dataset   "BICUBIC" set risk   gis:raster-sample risk-dataset self
      if pcolor != 12 OR pcolor != 17 AND int risk =  0                    [ set pcolor 47 ] ; Least
      if pcolor != 12 OR pcolor != 17 AND int risk >  0 AND int risk <  16 [ set pcolor 86 ] ; Low
      if pcolor != 12 OR pcolor != 17 AND int risk > 15 AND int risk <  46 [ set pcolor 68 ] ; Medium
      if pcolor != 12 OR pcolor != 17 AND int risk > 45 AND int risk <  78 [ set pcolor 25 ] ; High
      if pcolor != 12 OR pcolor != 17 AND int risk > 77 AND int risk < 101 [ set pcolor 15 ] ; Extreme
    ]
  ]
end
@#$#@#$#@
GRAPHICS-WINDOW
195
10
805
421
-1
-1
2.5
1
10
1
1
1
0
0
0
1
0
239
0
151
1
1
1
ticks

SWITCH
195
423
285
456
GIS-pest
GIS-pest
0
1
-1000

SWITCH
288
423
386
456
GIS-ashba
GIS-ashba
0
1
-1000

SWITCH
388
423
478
456
GIS-risk
GIS-risk
1
1
-1000

BUTTON
3
10
58
43
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
60
10
115
43
1 yr
if ticks = 0 [ tick ]\nifelse remainder ticks 365 != 0 [ go ][ tick stop ]
T
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
60
46
115
79
5 yrs
if ticks = 0 [ tick ]\nifelse remainder ticks 1825 != 0 [ go ][ tick stop ]\n
T
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
117
10
172
43
Once
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

MONITOR
3
47
53
92
Years
ticks / 365
0
1
11

MONITOR
3
120
67
165
# Beetles
count turtles
0
1
11

MONITOR
70
120
131
165
# Females
count turtles with [sex = \"female\"]
0
1
11

MONITOR
135
120
192
165
# Males
count turtles with [sex = \"male\"]
0
1
11

MONITOR
3
168
89
213
Ash Mortality
sum [ ashba ] of patches with [ health = \"dead\" ]
4
1
11

PLOT
814
31
1158
287
Population
Days
Beetles
0.0
10.0
0.0
10.0
true
true
PENS
"Eggs" 1.0 0 -13345367 true
"Larva" 1.0 0 -8630108 true
"Prepupa" 1.0 0 -6459832 true
"Pupa" 1.0 0 -955883 true
"Adult" 1.0 0 -2674135 true

MONITOR
68
215
125
260
larva
count turtles with [life-cycle-stage = \"larva\"]
0
1
11

MONITOR
127
215
183
260
prepupa
count turtles with [life-cycle-stage = \"prepupa\"]
0
1
11

MONITOR
9
215
66
260
egg
count turtles with [life-cycle-stage = \"egg\"]
0
1
11

MONITOR
32
263
89
308
pupa
count turtles with [life-cycle-stage = \"pupa\"]
0
1
11

MONITOR
93
263
150
308
adult
count turtles with [life-cycle-stage = \"adult\"]
0
1
11

SLIDER
3
344
175
377
larva-days-alive
larva-days-alive
0
24
23
1
1
NIL
HORIZONTAL

SLIDER
3
311
175
344
egg-days-alive
egg-days-alive
0
21
21
1
1
NIL
HORIZONTAL

SLIDER
3
377
175
410
prepupa-days-alive
prepupa-days-alive
0
169
168
1
1
NIL
HORIZONTAL

MONITOR
92
168
169
213
% Infested
(count patches with [health = \"infested\"]) / 26661 * 100
2
1
11

BUTTON
480
423
535
456
Display
ask patches\n[ if pcolor != 17 OR pcolor != 12\n  [ set pcolor 0 ]]\ndraw-world
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

TEXTBOX
677
427
806
445
Delaware County, Ohio
12
0.0
1

BUTTON
3
413
58
446
Beetles
ifelse hide\n[ ask turtles [ hide-turtle ] ]\n[ ask turtles [ show-turtle ] ]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

SWITCH
60
413
150
446
hide
hide
0
1
-1000

TEXTBOX
902
10
1052
28
Emerald Ash Borer Spread
12
0.0
1

SWITCH
58
83
188
116
use-random-seed
use-random-seed
1
1
-1000

@#$#@#$#@
WHAT IS IT?
-----------
This model integrates GIS data to explore population dynamics of an Emerald Ash Borer (EAB, Agrilus planipennis) infestation for Delaware County, Ohio, USA. It provides potential dispersal and forest health information which can be used to aid in risk management practices.


HOW IT WORKS
------------
Adult EAB emerge from infected host trees in late May to early August (BenDor et al. 2006), after which they feed on ash leaves for 5-7 days (BenDor et al. 2006). After feeding, the beetles disperse and mate, and then feed for another 5-7 days. Females are capable of laying 30-90 eggs throughout their lifespan, and can live for 3-6 weeks. 

Flight distances have been determined to be about 1.5 km/day for females (Poland et al. 2006). However, since the model doesnt account for the health of individual trees, it is assumed that a dispersal distance of 1-4 cells (270-1080 m) is sufficient.

Host cell selection is determined by verifying that the current cell is dead and allowing each emerging beetle to disperse randomly in one of eight directions towards a cell within a distance of 1-4 cells. If the new cell is healthy or infested, the beetle will stay and feed, otherwise it will repeat the dispersal process.


HOW TO USE IT
-------------
The model has been parameterized with daily juevinile mortality rates for beetles, and can be run for one day, one year, five years, or multiple years using combinations of the five and one year buttons. Mortality rates can be changed along a slider to simulate other possibilities. The default view is Ash Basal Area (m^2/ha), however, a risk map and the locations of infested traps can be viewed during the simulation. Agents can be hidden to show patterns of infested (pink) and dead (red) ash among the cells.

Due to the level of specificity for the population dynamics, it is recommended that the model not be run beyond eight years. The maximum number of agents was reached using a computer with 4 GB of RAM. While this may be a limitation, it is most likely inappropriate to run the model longer than 5-6 years without assessing the distribution of ash or beetles. It is also recommended that the model be run at a faster speed than normal, as the daily time steps do not cause significant changes to the view other than the plot.


THINGS TO NOTICE
----------------
As the beetle population grows and infested cells die off, patterns of the infestation become visible as cells can be classified by the time since death. Cells that have been attacked and are infested can contain healthy ash trees for 1-3 years before all trees die. Healthy cells are depicted by shades of green based on the basal area of ash, while infested cells are given a pink color and dead cells are changed to red.


THINGS TO TRY
-------------
Vary the number of adults at initialization or the mortality rates for juevinile beetles.


EXTENDING THE MODEL
-------------------
This model could be extended by including the reduction of basal area values from cells surrounding infested ones to simulate tree removals, a practice used to contain the spread and reduce the EAB population. 


NETLOGO FEATURES
----------------



RELATED MODELS
--------------
The two GIS models in the code examples use similar code to read and sample the GIS data. 


CREDITS AND REFERENCES
----------------------
Anulewicz AC, McCullough DG, Cappaert DL. 2007. Emerald Ash Borer (Agrilus planipennis) density and canopy dieback in three North American ash species. Arboriculture & Urban Forestry 33(5):338-349.

Bauer LS, Liu H, Gao R, Zhao T. 2005. Egg and larval parasitoids of emerald ash borer from China: potential for biocontrol in North America, pp. 48-49. In Emerald Ash Borer Research and Technology Development Meeting, Pittsburgh, PA, 26-27 Sept. 2005. V. Mastro, R. Reardon, and G. Parra, Eds. Morgantown, WV, U.S. Department of Agriculture, Forest Service publication FHTET-2005-16.

BenDor TK, Metcalf SS, Fontenot LE, Sangunett B, and Hannon B. 2006. Modeling the spread of the Emerald Ash Borer. Ecological Modelling. 197:221-236.

Cappaert D, McCullough DG, Poland TM, Siegert NW. 2005. Emerald ash borer in North America: A research and regulatory challenge. American Entomologist 51(3):152-165.

Poland TM, McCullough DG. 2006. Emerald Ash Borer: Invasion of the urban forest and the threat to North Americas ash resources. J. of Forestry. 104(3):118-124.

Prasad AM, Iverson LR, Peters MP, Bossenbroek J, and Sydnor D. 2010. Modeling the invasive emerald ash borer risk in Ohio, USA its mainly about roads. Landscape Ecology 25:353-369.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 4.1.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment1" repetitions="300" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2190"/>
    <metric>count turtles</metric>
    <metric>count turtles with [sex = "male"]</metric>
    <metric>count turtles with [sex = "female"]</metric>
    <metric>count turtles with [life-cycle-stage = "egg"]</metric>
    <metric>count turtles with [life-cycle-stage = "larva"]</metric>
    <metric>count turtles with [life-cycle-stage = "prepupa"]</metric>
    <metric>count turtles with [life-cycle-stage = "pupa"]</metric>
    <metric>count turtles with [life-cycle-stage = "adult"]</metric>
    <metric>sum [ ashba ] of patches with [ health = "dead" ]</metric>
    <metric>(count patches with [health = "infested"]) / 26661 * 100</metric>
    <enumeratedValueSet variable="hide">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-ashba">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="larva-days-alive">
      <value value="23"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="egg-days-alive">
      <value value="21"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-pest">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prepupa-days-alive">
      <value value="168"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-risk">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment2" repetitions="40" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2190"/>
    <metric>count turtles</metric>
    <metric>count turtles with [sex = "male"]</metric>
    <metric>count turtles with [sex = "female"]</metric>
    <metric>count turtles with [life-cycle-stage = "egg"]</metric>
    <metric>count turtles with [life-cycle-stage = "larva"]</metric>
    <metric>count turtles with [life-cycle-stage = "prepupa"]</metric>
    <metric>count turtles with [life-cycle-stage = "pupa"]</metric>
    <metric>count turtles with [life-cycle-stage = "adult"]</metric>
    <metric>sum [ ashba ] of patches with [ health = "dead" ]</metric>
    <metric>(count patches with [health = "infested"]) / 26661 * 100</metric>
    <enumeratedValueSet variable="hide">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-ashba">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="larva-days-alive">
      <value value="23"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="egg-days-alive">
      <value value="21"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-pest">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prepupa-days-alive">
      <value value="168"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="GIS-risk">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 1.0 0.0
0.0 1 1.0 0.0
0.2 0 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
